@@ -1,22 +1,8 @@
-#if defined(__x86_64__) && defined(__OPTIMIZE__)
+#if defined(__GNUC__) && (__GNUC__ >= 5)
 
-/* WARNING: this only works if compiled with -fomit-frame-pointer */
-void imult64() {
-  asm volatile(
-    "xchgq %rdx,%rsi\n"
-    "movq %rdi,%rax\n"
-    "imulq %rdx\n"
-    "jc 1f\n"	/* overflow */
-    "movq %rax,(%rsi)\n"
-    "xorq %rax,%rax\n"
-    "inc %rax\n"
-    "ret\n"
-    "1:\n"
-    "xorq %rax,%rax\n"
-    /* the closing ret is renerated by gcc */
-    );
-}
+#include "uint64.h"
 
+int imult64( int64 a, int64 b, int64* c) { return !__builtin_mul_overflow(a,b,c); }
 
 #else
 
