@@ -1,26 +1,13 @@
-#include "haveuint128.h"
+#if defined(__GNUC__) && (__GNUC__ >= 5)
 
-#if defined(__x86_64__) && defined(__OPTIMIZE__)
+#include "uint64.h"
 
-/* WARNING: this only works if compiled with -fomit-frame-pointer */
-void umult64() {
-  asm volatile(
-    "xchgq %rdx,%rsi\n"
-    "movq %rdi,%rax\n"
-    "mulq %rdx\n"
-    "jc 1f\n"	/* overflow */
-    "movq %rax,(%rsi)\n"
-    "xorq %rax,%rax\n"
-    "inc %rax\n"
-    "ret\n"
-    "1:\n"
-    "xorq %rax,%rax\n"
-    /* the closing ret is renerated by gcc */
-    );
-}
+int umult64(uint64 a,uint64 b,uint64* c) { return !__builtin_mul_overflow(a,b,c); }
 
 #else
 
+#include "haveuint128.h"
+
 #include "safemult.h"
 
 #if defined(HAVE_UINT128)
