@@ -23,7 +23,8 @@ size_t fmt_urlencoded2(char* dest,const char* src,size_t len,const char* escapem
       }
       written+=3;
     } else {
-      if (dest) dest[written]=s[i]; ++written;
+      if (dest) dest[written]=s[i];
+      ++written;
     }
     /* in case someone gives us malicious input */
     if (written>((size_t)-1)/2) return (size_t)-1;
