@@ -19,7 +19,7 @@ size_t scan_base64(const char *src,char *dest,size_t *destlen) {
   for (;;) {
     int a=dec(*s);
     if (a<0) {
-      while (*s=='=') ++s;
+      while (*s=='=' && ((s-(const unsigned char*)src)&3)) ++s;
       break;
     }
     tmp=(tmp<<6)|a; bits+=6;
